Module: LesliTesting

Defined in:
lib/lesli_testing/engine.rb,
lib/lesli_testing.rb,
lib/lesli_testing/testers.rb,
lib/lesli_testing/version.rb,
lib/lesli_testing/coverage.rb,
lib/lesli_testing/fixtures.rb,
lib/lesli_testing/minitest/cli_reporter.rb

Overview

Lesli

Copyright © 2026, Lesli Technologies, S. A.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.

Lesli · Ruby on Rails SaaS Development Framework.

Made with ♥ by LesliTech Building a better future, one line of code at a time.

// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·

Defined Under Namespace

Modules: Coverage, Fixtures, Reporters Classes: Engine, Error, IntegrationTester, ModelTester, ViewTester

Constant Summary collapse

VERSION =
"1.3.1"
BUILD =
"1776563517"

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.app_moduleObject

Returns the value of attribute app_module.



44
45
46
# File 'lib/lesli_testing.rb', line 44

def app_module
  @app_module
end

.app_nameObject

Returns the value of attribute app_name.



45
46
47
# File 'lib/lesli_testing.rb', line 45

def app_name
  @app_name
end

.options=(value) ⇒ Object

Sets the attribute options

Parameters:

  • value

    the value to set the attribute options to.



46
47
48
# File 'lib/lesli_testing.rb', line 46

def options=(value)
  @options = value
end

Class Method Details

.app(name, options = {}) ⇒ Object



48
49
50
# File 'lib/lesli_testing.rb', line 48

def app(name, options = {})
    configure(name, options.merge(coverage_profile: "app"))
end

.engine(name, options = {}) ⇒ Object



52
53
54
# File 'lib/lesli_testing.rb', line 52

def engine(name, options = {})
    configure(name, options.merge(coverage_profile: "engine"))
end

.gem(name, options = {}) ⇒ Object



56
57
58
# File 'lib/lesli_testing.rb', line 56

def gem(name, options = {})
    configure(name, options.merge(coverage_profile: "gem"))
end