Class: LesliTesting::ViewTester

Inherits:
ActionView::TestCase
  • Object
show all
Defined in:
lib/lesli_testing/testers.rb

Class Method Summary collapse

Class Method Details

.inherited(subclass) ⇒ Object

We use a hook to include the helpers only when the class is used. This ensures Lesli core is fully loaded by Rails before we ask for the helpers.



50
51
52
53
54
55
56
# File 'lib/lesli_testing/testers.rb', line 50

def self.inherited(subclass)
    super
    subclass.class_eval do
        include Lesli::HtmlHelper   if defined?(Lesli::HtmlHelper)
        include Lesli::SystemHelper if defined?(Lesli::SystemHelper)
    end
end